@@ -1,4 +1,4 @@
-# Copyright (C) 2014 Julian Marchant <onpon4@riseup.net>
+# Copyright (C) 2014, 2016 onpon4 <onpon4@riseup.net>
 # 
 # This file is part of the Pygame SGE.
 # 
@@ -107,30 +107,30 @@ def rectangle(x, y, w, h, other=None):
     - ``w`` -- The width of the rectangle.
     - ``h`` -- The height of the rectangle.
     - ``other`` -- What to check for collisions with.  See the
-      documentation for :meth:`sge.StellarClass.collision` for more
+      documentation for :meth:`sge.dsp.Object.collision` for more
       information.
     """
     room = sge.game.current_room
-    areas = r._get_rectangle_collision_areas(x, y, w, h)
-    others = r._get_others(areas, other)
+    others = room.get_objects_at(x, y, w, h)
     collisions = []
     mask_id = ("rectangle_masks", x, y, w, h)
 
     mask = r.cache.get(mask_id)
     if mask is None:
-        mask = [[True for j in six.moves.range(h)] for i in six.moves.range(w)]
+        mask = [[True for j in six.moves.range(int(h))]
+                for i in six.moves.range(int(w))]
 
     r.cache.add(mask_id, mask)
 
-    for other in others:
-        if other.collision_precise or other.collision_ellipse:
-            if masks_collide(x, y, mask, other.mask_x, other.mask_y,
-                             other.mask):
-                collisions.append(other)
-        else:
-            if rectangles_collide(x, y, w, h, other.bbox_left, other.bbox_top,
-                                  other.bbox_width, other.bbox_height):
-                collisions.append(other)
+    for obj in others:
+        if r.o_is_other(obj, other):
+            if obj.collision_precise or obj.collision_ellipse:
+                if masks_collide(x, y, mask, obj.mask_x, obj.mask_y, obj.mask):
+                    collisions.append(obj)
+            else:
+                if rectangles_collide(x, y, w, h, obj.bbox_left, obj.bbox_top,
+                                      obj.bbox_width, obj.bbox_height):
+                    collisions.append(obj)
 
     return collisions
 
@@ -148,20 +148,19 @@ def ellipse(x, y, w, h, other=None):
     - ``w`` -- The width of the ellipse.
     - ``h`` -- The height of the ellipse.
     - ``other`` -- What to check for collisions with.  See the
-      documentation for :meth:`sge.StellarClass.collision` for more
+      documentation for :meth:`sge.dsp.Object.collision` for more
       information.
     """
     room = sge.game.current_room
-    areas = r._get_rectangle_collision_areas(x, y, w, h)
-    others = r._get_others(areas, other)
+    others = room.get_objects_at(x, y, w, h)
     collisions = []
     mask_id = ("ellipse_masks", x, y, w, h)
 
     mask = r.cache.get(mask_id)
 
     if mask is None:
-        mask = [[False for j in six.moves.range(h)]
-                for i in six.moves.range(w)]
+        mask = [[False for j in six.moves.range(int(h))]
+                for i in six.moves.range(int(w))]
         a = len(mask) / 2
         b = len(mask[0]) / 2 if mask else 0
 
@@ -172,10 +171,10 @@ def ellipse(x, y, w, h, other=None):
 
     r.cache.add(mask_id, mask)
 
-    for other in others:
-        if masks_collide(x, y, mask, other.mask_x, other.mask_y,
-                         other.mask):
-            collisions.append(other)
+    for obj in others:
+        if (r.o_is_other(obj, other) and
+                masks_collide(x, y, mask, obj.mask_x, obj.mask_y, obj.mask)):
+            collisions.append(obj)
 
     return collisions
 
@@ -190,21 +189,20 @@ def circle(x, y, radius, other=None):
     - ``y`` -- The vertical position of the center of the circle.
     - ``radius`` -- The radius of the circle.
     - ``other`` -- What to check for collisions with.  See the
-      documentation for :meth:`sge.StellarClass.collision` for more
+      documentation for :meth:`sge.dsp.Object.collision` for more
       information.
     """
     room = sge.game.current_room
     diameter = radius * 2
-    areas = r._get_rectangle_collision_areas(x, y, diameter, diameter)
-    others = r._get_others(areas, other)
+    others = room.get_objects_at(x - radius, y - radius, diameter, diameter)
     collisions = []
     mask_id = ("circle_masks", x, y, radius)
 
     mask = r.cache.get(mask_id)
 
     if mask is None:
-        mask = [[False for j in six.moves.range(diameter)]
-                for i in six.moves.range(diameter)]
+        mask = [[False for j in six.moves.range(int(diameter))]
+                for i in six.moves.range(int(diameter))]
 
         for i in six.moves.range(len(mask)):
             for j in six.moves.range(len(mask[i])):
@@ -213,10 +211,11 @@ def circle(x, y, radius, other=None):
 
     r.cache.add(mask_id, mask)
 
-    for other in others:
-        if masks_collide(x - radius, y - radius, mask, other.mask_x,
-                         other.mask_y, other.mask):
-            collisions.append(other)
+    for obj in others:
+        if (r.o_is_other(obj, other) and
+                masks_collide(x - radius, y - radius, mask, obj.mask_x,
+                              obj.mask_y, obj.mask)):
+            collisions.append(obj)
 
     return collisions
 
@@ -236,7 +235,7 @@ def line(x1, y1, x2, y2, other=None):
     - ``y2`` -- The vertical position of the second endpoint of the line
       segment.
     - ``other`` -- What to check for collisions with.  See the
-      documentation for :meth:`sge.StellarClass.collision` for more
+      documentation for :meth:`sge.dsp.Object.collision` for more
       information.
     """
     room = sge.game.current_room
@@ -244,16 +243,15 @@ def line(x1, y1, x2, y2, other=None):
     y = min(y1, y2)
     w = abs(x2 - x1)
     h = abs(y2 - y1)
-    areas = r._get_rectangle_collision_areas(x, y, w, h)
-    others = r._get_others(areas, other)
+    others = room.get_objects_at(x , y, w, h)
     collisions = []
     mask_id = ("line_masks", w, h)
 
     mask = r.cache.get(mask_id)
 
     if mask is None:
-        mask = [[False for j in six.moves.range(h)]
-                for i in six.moves.range(w)]
+        mask = [[False for j in six.moves.range(int(h))]
+                for i in six.moves.range(int(w))]
         m = h / w
         b = y1 - m * x1
 
@@ -264,9 +262,9 @@ def line(x1, y1, x2, y2, other=None):
 
     r.cache.add(mask_id, mask)
 
-    for other in others:
-        if masks_collide(x, y, mask, other.mask_x, other.mask_y,
-                         other.mask):
-            collisions.append(other)
+    for obj in others:
+        if (r.o_is_other(obj, other) and
+                masks_collide(x, y, mask, obj.mask_x, obj.mask_y, obj.mask)):
+            collisions.append(obj)
 
     return collisions
