@@ -780,7 +780,7 @@ def r_get_rectangle_object_areas(self, x, y, width, height):
     return areas
 
 
-def r_set_object_areas(self):
+def r_set_object_areas(self, update_objects=True):
     self.object_areas = []
     for i in six.moves.range(0, self.width, self.object_area_width):
         column = [set() for j in six.moves.range(0, self.height,
@@ -789,8 +789,9 @@ def r_set_object_areas(self):
 
     self.object_area_void = set()
 
-    for obj in self.objects:
-        o_update_object_areas(obj)
+    if update_objects:
+        for obj in self.objects:
+            o_update_object_areas(obj)
 
 
 def r_update_fade(self, complete):
@@ -1058,14 +1059,8 @@ def s_set_transparency(self, image):
         color = pygame.Color(*self.transparent)
         img.set_colorkey(color, pygame.RLEACCEL)
         return img
-    elif self.transparent and image.get_width() > 0:
-        if image.get_flags() & pygame.SRCALPHA:
-            return image.convert_alpha()
-        else:
-            img = image.convert()
-            color = image.get_at((image.get_width() - 1, 0))
-            img.set_colorkey(color, pygame.RLEACCEL)
-            return img
+    elif self.transparent:
+        return image.convert_alpha()
     else:
         return image.convert()
 
@@ -1075,13 +1070,15 @@ def s_set_transparency(self, image):
 
 
 def s_get_image(self, num, xscale=1, yscale=1, rotation=0, alpha=255,
-                blend=None):
+                blend=None, blend_mode=None):
     if isinstance(self, sge.gfx.Sprite):
         num %= self.frames
+        if blend_mode is None:
+            blend_mode = sge.BLEND_RGB_MULTIPLY
 
         i = ("s_image", weakref.ref(self), self.rd["drawcycle"], num, xscale,
              yscale, rotation, alpha,
-             tuple(blend) if blend is not None else None)
+             tuple(blend) if blend is not None else None, blend_mode)
         img = cache.get(i)
         if img is None:
             if xscale != 0 and yscale != 0:
@@ -1095,17 +1092,18 @@ def s_get_image(self, num, xscale=1, yscale=1, rotation=0, alpha=255,
                 if rotation != 0:
                     img = pygame.transform.rotate(img, -rotation)
 
+                alpha = int(alpha)
                 if alpha < 255:
                     if img.get_flags() & pygame.SRCALPHA:
                         # Have to do this the more difficult way.
-                        img.fill((0, 0, 0, 255 - alpha), None,
-                                 pygame.BLEND_RGBA_SUB)
+                        img.fill((255, 255, 255, alpha), None,
+                                 pygame.BLEND_RGBA_MULT)
                     else:
                         img.set_alpha(alpha, pygame.RLEACCEL)
 
                 if blend is not None:
-                    img.fill(pygame.Color(*blend), None,
-                             pygame.BLEND_RGB_MULT)
+                    pygame_flags = _get_blend_flags(blend_mode)
+                    img.fill(pygame.Color(*blend), None, pygame_flags)
             else:
                 img = pygame.Surface((1, 1))
                 img.set_colorkey((0, 0, 0), pygame.RLEACCEL)
